==> gchempaint-0.5.1.tar.gz: gchempaint-0.5.1/plugins/selection/selectiontool.h <==
// -*- C++ -*-

/* 
 * GChemPaint selection plugin
 * selectiontool.h 
 *
 * Copyright (C) 2001-2004
 *
 * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef GCHEMPAINT_SELECTION_TOOL_H
#define GCHEMPAINT_SELECTION_TOOL_H

#include "lib/tool.h"

class gcpWidgetData;
class gcpApplication;

class gcpSelectionTool: public gcpTool
{
public:
	gcpSelectionTool(gcpApplication *App);
	virtual ~gcpSelectionTool();

	virtual bool OnClicked();
	virtual void OnDrag();
	virtual void OnRelease();
	virtual void Activate();
	virtual bool Deactivate();
	virtual bool OnRightButtonClicked ();

	void AddSelection(gcpWidgetData* data);
	void OnFlip (bool horizontal);
	void Rotate (bool rotate);
	void Merge ();

	void CreateGroup ();

private:
	std::list<gcpWidgetData*> SelectedWidgets;
	bool m_bRotate;
	double m_cx, m_cy;
	double m_dAngle, m_dAngleInit;
	gcpOperation* m_pOp;
	GtkUIManager *m_UIManager;
	TypeId m_Type;
	list<int> m_uiIds;
};

#endif // GCHEMPAINT_SELECTION_TOOL_H

==> gchempaint-0.5.4.tar.gz: gchempaint-0.5.4/plugins/selection/selectiontool.h <==
// -*- C++ -*-

/* 
 * GChemPaint selection plugin
 * selectiontool.h 
 *
 * Copyright (C) 2001-2004
 *
 * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef GCHEMPAINT_SELECTION_TOOL_H
#define GCHEMPAINT_SELECTION_TOOL_H

#include "lib/tool.h"

class gcpWidgetData;
class gcpApplication;

class gcpSelectionTool: public gcpTool
{
public:
	gcpSelectionTool(gcpApplication *App);
	virtual ~gcpSelectionTool();

	virtual bool OnClicked();
	virtual void OnDrag();
	virtual void OnRelease();
	virtual void Activate();
	virtual bool Deactivate();
	virtual bool OnRightButtonClicked (GtkUIManager *UIManager);

	void AddSelection(gcpWidgetData* data);
	void OnFlip (bool horizontal);
	void Rotate (bool rotate);
	void Merge ();

	void CreateGroup ();
	void Group ();

private:
	std::list<gcpWidgetData*> SelectedWidgets;
	bool m_bRotate;
	double m_cx, m_cy;
	double m_dAngle, m_dAngleInit;
	gcpOperation* m_pOp;
	TypeId m_Type;
	list<int> m_uiIds;
};

#endif // GCHEMPAINT_SELECTION_TOOL_H
